:mod:`collection` -- Collection level utilities for MongoLab
------------------------------------------------------------

.. automodule:: pymongolab.collection
    :synopsis: Collection level utilities for MongoLab
    :members:
    :undoc-members:
    :show-inheritance:
